package com.usky.dxtop.service.impl;

import cn.afterturn.easypoi.excel.ExcelImportUtil;
import cn.afterturn.easypoi.excel.entity.ImportParams;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.common.utils.BeanMapperUtils;
import com.usky.dxtop.common.utils.StringUtils;
import com.usky.dxtop.model.Company;
import com.usky.dxtop.model.DreMenu;
import com.usky.dxtop.mapper.DreMenuMapper;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.DreMenuService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.usky.dxtop.service.vo.DreMenuFileVO;
import com.usky.dxtop.service.vo.OrderFileVO;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2022-08-14
 */
@Service
public class DreMenuServiceImpl extends ServiceImpl<DreMenuMapper, DreMenu> implements DreMenuService {

    @Override
    public void addBatchByFile(MultipartFile file) {
        this.saveBatch(getListByFile(file));
    }

    @Override
    public CommonPage<DreMenu> page(Integer current, Integer size, String type, String name, Integer isRecommend, Integer status) {
        IPage<DreMenu> page = new Page<>(current, size);
        LambdaQueryWrapper<DreMenu> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper
                .eq(StringUtils.isNotBlank(type),DreMenu::getType,type)
                .like(StringUtils.isNotBlank(name),DreMenu::getName,name)
                .eq(null != isRecommend,DreMenu::getIsRecommend,isRecommend)
                .eq(null != status,DreMenu::getStatus,status)
                .orderByDesc(DreMenu::getId);
        page = this.page(page,queryWrapper);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }


    public List<DreMenu> getListByFile(MultipartFile multipartFile){
        ImportParams importParams = new ImportParams();
        importParams.setHeadRows(1);
        try {
            List<DreMenuFileVO> dreMenuFileVOS = ExcelImportUtil.importExcel(
                    multipartFile.getInputStream(),
                    DreMenuFileVO.class,
                    importParams
            );
            if (CollectionUtils.isEmpty(dreMenuFileVOS)){
                throw new CustomException("表格数据为空");
            }
            List<DreMenu> dreMenus = BeanMapperUtils.mapList(dreMenuFileVOS, DreMenuFileVO.class, DreMenu.class);
            long count = dreMenuFileVOS.stream().filter(order -> null == order.getPrice() && order.getPrice().compareTo(BigDecimal.ZERO) == 0).count();
            if (count > 0){
                throw new CustomException("菜品单价不能为空");
            }
            long count1 = dreMenuFileVOS.stream().filter(order -> StringUtils.isBlank(order.getType())).count();
            if (count1 > 0){
                throw new CustomException("菜品类型不能为空");
            }
            long count2 = dreMenuFileVOS.stream().filter(order -> StringUtils.isBlank(order.getName())).count();
            if (count2 > 0){
                throw new CustomException("菜品名称不能为空");
            }
            long count3 = dreMenuFileVOS.stream().filter(order -> null != order.getIsRecommend()).count();
            if (count3 > 0){
                throw new CustomException("是否上下架不能为空");
            }
            return dreMenus;
        }catch (Exception e){
            throw new CustomException("解析菜品文件异常,检查表格格式"+e.getMessage());
        }
    }
}
