package com.usky.dxtop.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.ProductInfo;
import com.usky.dxtop.model.ProductPeriod;
import com.usky.dxtop.mapper.ProductPeriodMapper;
import com.usky.dxtop.service.ProductPeriodService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.security.core.parameters.P;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author yq
 * @since 2022-07-08
 */
@Service
public class ProductPeriodServiceImpl extends ServiceImpl<ProductPeriodMapper, ProductPeriod> implements ProductPeriodService {

    @Override
    public void removeByProductInfo(Long productInfoId) {
        LambdaQueryWrapper<ProductPeriod> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ProductPeriod::getProductInfoId,productInfoId);
        this.remove(queryWrapper);
    }

    @Override
    public void insertList(ProductInfo productInfo) {
        if (CollectionUtils.isEmpty(productInfo.getCysles())){
            throw new CustomException("循环周期不能为空");
        }
        this.saveBatch(productInfo.getCysles().stream()
                .map(s -> {
                    ProductPeriod productPeriod = new ProductPeriod();
                    productPeriod.setProductInfoId(productInfo.getId());
                    productPeriod.setPeriod(s);
                    return productPeriod;
                }).collect(Collectors.toList()));
    }

    @Override
    public List<ProductPeriod> list(Long productInfoId) {
        LambdaQueryWrapper<ProductPeriod> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(ProductPeriod::getProductInfoId,productInfoId);
        return this.list(queryWrapper);
    }
}
